# Experimentální Textová hra Evropská Unie 2020

Staňte se vládcem Evropské Unie a vyzkoušejte zda byste byli schopni uspokojit zájmy všech člsenských států a dalších temných zájmových skupin.

Hra stále není hotová - jedná se jen o prototyp.

## Spuštění

Udělejte si klon repozitáře a spusťte hru následujícím příkazem.

```
python -m pip install -r requirements.txt
python -m eu2020
```

## Spolupráce

Pokud vás napadne jakékoliv vylepšení tak neváhejte vytvořit issue nebo pull request.
